#
# spec file for package rubber
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           rubber
Version:        1.6.0
Release:        1.12
Summary:        An automated system for building LaTeX documents
License:        GPL-2.0-only
Group:          Productivity/Publishing/TeX/Utilities
URL:            https://launchpad.net/rubber
Source:         https://gitlab.com/latex-rubber/rubber/-/archive/%{version}/%{name}-%{version}.tar.bz2
BuildRequires:  fdupes
BuildRequires:  makeinfo
BuildRequires:  python3-devel
BuildRequires:  texinfo
Requires:       python3
Requires:       texlive-latex
Requires(post): info
BuildArch:      noarch

%description
Rubber is a building system for LaTeX documents. It is based on a routine that
runs just as many compilations as necessary. The module system provides a
great flexibility that virtually allows support for any package with no user
intervention, as well as pre- and post-processing of the document. The
standard modules currently provide support for bibtex, dvips, dvipdfm, pdftex,
makeindex. A good number of standard packages are supported, including
graphics/graphicx (with automatic conversion between various formats and
Metapost compilation).

%prep
%setup -q

%build
python3 setup.py build

%install
python3 setup.py install --root=%{buildroot} --mandir=%{_mandir} --infodir=%{_infodir} --docdir=%{_docdir}/%{name}

%fdupes %{buildroot}%{python3_sitelib}/rubber/

%post
install-info %{_infodir}/rubber.info.gz %{_infodir}/dir

%postun
install-info --delete %{_infodir}/rubber.info.gz %{_infodir}/dir

%files
%doc NEWS README
%license COPYING
%{_bindir}/rubber
%{_bindir}/rubber-pipe
%{_bindir}/rubber-info
%{_bindir}/rubber-lsmod
%{python3_sitelib}/rubber/
%{python3_sitelib}/rubber-%{version}-py%{py3_ver}.egg-info
%{_mandir}/man1/rubber-info.1%{?ext_man}
%{_mandir}/man1/rubber-pipe.1%{?ext_man}
%{_mandir}/man1/rubber.1%{?ext_man}
%{_infodir}/rubber.info%{?ext_info}
%{_mandir}/fr/man1/*.gz
%{_docdir}/%{name}/

%changelog
* Thu Jun 17 2021 Matthias Mailänder <mailaender@opensuse.org>
- Update to version 1.6.0
  + Add support for LuaTeX via the lualatex module
  + Introduce rubbercache for faster compilations
* Thu Jan  9 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.5.1:
  + Restore support for 8-bits encoded .tex sources (Debian:
    [#907937], #907988).
  + Fix many crashing log/warning/error messages.
- Changes from versin 1.5.0:
  + Requires python 3.
  + Remove support for selection of paper size and orientation.
  + Prohibit onchange directive unless --unsafe mode.
  + Fix stacktrace when parsing BibTeX errors (LP: #1533723).
  + Use open mode r+ for /dev/null instead of rw (LP: #1543622)
  + Always give a relative source path to fig2dev (Debian:
    [#345954]).
  + Detect "Missing character" messages in log files (Debian:
    [#384155]).
  + Update hooks for all parsers (Debian: #813855, LP: #1470988).
  + Accept uppercase image extensions (LP: #1583475).
- Drop rubber-makeinfo-unsupported-option.patch: no longer needed
  for any supported openSUSE version.
- Switch BuildRequires, Requires, and macros to python3
  equivalents.
- Link duplicate files using fdupes.
* Mon Jul 18 2016 badshah400@gmail.com
- Add rubber-makeinfo-unsupported-option.patch to fix building
  on openSUSE <= 13.2, where makeinfo does not support the
  "--info" option.
* Mon Jul 18 2016 badshah400@gmail.com
- Update to version 1.4:
  + New distutils-based build & install scripts by Nicolas.
  + Report BibTeX / Biber errors more reliably.
  + We have support for embedding R code via knitr.
    http://yihui.name/knitr/
    Closes: https://bugs.launchpad.net/rubber/+bug/1422759
    Note that since R can run arbitrary external code, --unsafe
    must be given at the command line:
    rubber -d --unsafe paper.Rtex
    creates beautifully typeset PDF from your R script.
  + Support for PythonTeX package.  Also requires --unsafe if
    you want Rubber to invoke pythontex.
  + Rubber will no longer attempt to use jpeg2ps on its own, which
    has been superseded by sam2p.  (You can add it back by
    providing your own rules.ini.)
  + More refactoring, reducing the number of code paths to test and
    maintain.
  + Bugs fixed: lp#628150, lp#975376, lp#1090115.
- Also package HTML and PDF documentation in main package
  (documentation files are rather small and do not warrant a
  separate doc pkg).
- Drop conditionals and macro definitions for ancient distro
  versions.
- Add BuildRequires: texinfo, required for building PDF
  documentation.
* Sat Oct 27 2012 coolo@suse.com
- we also need to require info for %%post scripts
* Fri Sep  7 2012 coolo@suse.com
- add explicit buildrequire makeinfo
* Sat Sep 25 2010 badshah400@gmail.com
- Remove texlive texlive-bin texlive-bin-latex from Requires,
  texlive automatically pulls them in
- Lots of miscellaneous cleanup in the spec file
* Mon Aug  2 2010 badshah400@gmail.com
- spec file cleanup
* Sun Aug  1 2010 badshah400@gmail.com
- Intital package from upstream (development snapshot
  v20090819)
